#include "edit.h"


CEdit::CEdit(QWidget*parent,const char*name)
    :QTextEdit(parent,name)
{
    setFocusPolicy(QWidget::StrongFocus);
    //    setTextFormat(Qt::PlainText);
    //    setTextFormat(Qt::RichText);
    setWordWrap(QTextEdit::NoWrap);
    setText("");
    setReadOnly(false);
}

CEdit::~CEdit()
{
}

void CEdit::keyPressEvent(QKeyEvent*e)
{
    QTextEdit::keyPressEvent(e);
    emit cursormove();
}

void CEdit::focusInEvent(QFocusEvent*e)
{
    QTextEdit::focusInEvent(e);
    emit cursormove();
}

void CEdit::mouseReleaseEvent(QMouseEvent*e)
{
    QTextEdit::mouseReleaseEvent(e);
    emit cursormove();
}
